@@ -18,6 +18,7 @@ import System.Posix.Files
 import System.ProgressBar
 import TermSize
 import qualified Data.MyText as T
+import Data.Time.LocalTime
 
 import TimeLog
 import Categorize
@@ -48,7 +49,7 @@ defaultOptions dir = Options
     , optLogFile = dir </> "capture.log"
     , optCategorizeFile = dir </> "categorize.cfg"
     }
-    
+
 versionStr, header :: String
 versionStr = "arbtt-stats " ++ showVersion version
 header = "Usage: arbtt-stats [OPTIONS...]"
@@ -91,7 +92,7 @@ options =
               "only consider samples matching the condition"
      , Option "m"       ["min-percentage"]
               (ReqArg (\arg opt -> let ro = (optReportOptions opt) { roMinPercentage = read arg}
-                                   in  return opt { optReportOptions = ro }) "COND")
+                                   in  return opt { optReportOptions = ro }) "PERC")
               "do not show tags with a percentage lower than PERC% (default: 1)"
      , Option ""        ["output-exclude"]
               (ReqArg (\arg opt -> let filters = ExcludeActivity (parseActivityMatcher arg) : roActivityFilter (optReportOptions opt)
@@ -141,10 +142,12 @@ options =
 readRepeater :: String -> Repeater
 readRepeater arg =
     case map toLower arg of
-        "day"   -> ByDay
-        "month" -> ByMonth
-        "year"  -> ByYear
-        _       -> error ("Unsupported parameter to --for-each: '" ++ arg ++ "'")
+        "minute" -> ByMinute
+        "hour"   -> ByHour
+        "day"    -> ByDay
+        "month"  -> ByMonth
+        "year"   -> ByYear
+        _        -> error ("Unsupported parameter to --for-each: '" ++ arg ++ "'")
 
 readReportFormat :: String -> ReportFormat
 readReportFormat arg =
@@ -163,6 +166,7 @@ main = do
           (_,_,errs) -> do
                 hPutStr stderr (concat errs ++ usageInfo header options)
                 exitFailure
+  tz <- getCurrentTimeZone
 
   dir <- getAppUserDataDirectory "arbtt"
   flags <- foldl (>>=) (return (defaultOptions dir)) actions
@@ -175,12 +179,12 @@ main = do
   categorizer <- readCategorizer (optCategorizeFile flags)
 
   timelog <- BS.readFile (optLogFile flags)
-  size <- fileSize <$> getFileStatus (optLogFile flags)
   isTerm <- hIsTerminalDevice stderr
 
   trackedTimelog <- case isTerm of
     True -> do
       hSetBuffering stderr NoBuffering
+      size <- fileSize <$> getFileStatus (optLogFile flags)
       trackProgressWithChunkSize (fromIntegral size `div` 100) (\_ b -> do
         (_height, width) <- getTermSize
         hPutChar stderr '\r'
@@ -195,28 +199,26 @@ main = do
 
   let captures = parseTimeLog trackedTimelog
   let allTags = categorizer captures
+
   when (null allTags) $ do
      putStrLn "Nothing recorded yet"
      exitFailure
-      
+
   let filters = (if optAlsoInactive flags then id else (defaultFilter:)) $ optFilters flags
 
   let rep = case optReports flags of
                 [] -> TotalTime
                 [x] -> x
                 _ -> error "Please specify exactly one report to generate"
-  let repeater = foldr (.) id $ map processRepeater (optRepeater flags)
+  let repeater = foldr (.) id $ map (processRepeater tz) (optRepeater flags)
 
-  -- These are defined here, but of course only evaluated when any report
-  -- refers to them. Some are needed by more than one report, which is then
-  -- advantageous.
   let opts = optReportOptions flags
   let fold = filterPredicate filters `adjoin` repeater (processReport opts rep)
   let result = runLeftFold fold allTags
 
   -- Force the results a bit, to ensure the progress bar to be shown before the title
   result `seq` return ()
-  
+
   renderReport opts result
 
 {-
